"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _core = require("@material-ui/core");

var _usefulState = require("useful-state");

var _lodash = require("lodash");

var _q3UiLocale = require("q3-ui-locale");

var _FileManagerAuthContext = _interopRequireDefault(require("../FileManagerAuthContext"));

var _FileManagerBatchContext = _interopRequireDefault(require("../FileManagerBatchContext"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ContextMenu = ({
  id,
  items,
  children
}) => {
  const {
    t
  } = (0, _q3UiLocale.useTranslation)('labels');
  const {
    open,
    isOpen,
    close,
    anchorEl
  } = (0, _usefulState.useOpen)();

  const {
    enable,
    disable,
    select
  } = _react.default.useContext(_FileManagerBatchContext.default);

  const authContext = _react.default.useContext(_FileManagerAuthContext.default);

  const checkAuth = prop => prop ? !(0, _lodash.get)(authContext, prop, true) : false;

  const handleBackdropContextMenu = e => {
    if (!isOpen) return;
    (0, _utils.suppressEvent)(e, close);
  };

  const handleOnClick = fn => e => {
    fn(e);
    close(e);
  };

  const handleOnContext = e => {
    (0, _utils.suppressEvent)(e, open);
    select(id);
    disable();
  };

  const handleClose = e => {
    close(e);
    enable();
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children(handleOnContext), /*#__PURE__*/_react.default.createElement(_core.Menu, {
    BackdropProps: {
      invisible: true,
      onContextMenu: handleBackdropContextMenu
    },
    anchorEl: anchorEl,
    className: "q3-context-menu",
    open: isOpen,
    onClose: handleClose
  }, (0, _lodash.map)(items, ({
    auth,
    divider,
    icon,
    label,
    onClick
  }, idx) => divider ? /*#__PURE__*/_react.default.createElement(_core.Divider, {
    key: idx,
    component: "li",
    style: {
      marginBottom: '.5rem',
      marginTop: '.5rem'
    }
  }) : /*#__PURE__*/_react.default.createElement(_core.MenuItem, {
    button: true,
    dense: true,
    disabled: checkAuth(auth),
    component: "li",
    key: label,
    onClick: handleOnClick(onClick)
  }, /*#__PURE__*/_react.default.createElement(_core.ListItemIcon, null, icon), t(label)))));
};

ContextMenu.defaultProps = {
  items: []
};
ContextMenu.propTypes = {
  children: _propTypes.default.func.isRequired,
  id: _propTypes.default.string.isRequired,
  items: _propTypes.default.arrayOf(_propTypes.default.shape({
    label: _propTypes.default.string,
    onClick: _propTypes.default.func
  }))
};

var _default = /*#__PURE__*/_react.default.memo(ContextMenu);

exports.default = _default;