"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _CircularProgress = _interopRequireDefault(require("@material-ui/core/CircularProgress"));

var _AlertAuthError = _interopRequireDefault(require("../AlertAuthError"));

var _AlertFetchingError = _interopRequireDefault(require("../AlertFetchingError"));

var _Directory = _interopRequireDefault(require("../Directory"));

var _FileManagerAuthContext = _interopRequireDefault(require("../FileManagerAuthContext"));

var _FileManagerContext = _interopRequireDefault(require("../FileManagerContext"));

var _FileManagerCurrentContext = _interopRequireDefault(require("../FileManagerCurrentContext"));

var _useUploads = _interopRequireDefault(require("../useUploads"));

var _useUploadsAuth = _interopRequireDefault(require("../useUploadsAuth"));

var _useCurrent = _interopRequireDefault(require("../useCurrent"));

var _useFileManagerInit = _interopRequireDefault(require("../useFileManagerInit"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const FileManager = ({
  collectionName,
  id,
  initialView,
  ...rest
}) => {
  const currentState = (0, _useCurrent.default)();
  const auth = (0, _useUploadsAuth.default)(collectionName, rest);
  const {
    get,
    poll,
    fetching,
    fetchingError,
    ...uploadState
  } = (0, _useUploads.default)(collectionName, id);
  const init = (0, _useFileManagerInit.default)(auth, get, poll);
  if (!init || fetching) return /*#__PURE__*/_react.default.createElement(_CircularProgress.default, null);
  if (!auth.canSee) return /*#__PURE__*/_react.default.createElement(_AlertAuthError.default, null);
  if (fetchingError) return /*#__PURE__*/_react.default.createElement(_AlertFetchingError.default, null);
  return /*#__PURE__*/_react.default.createElement(_FileManagerAuthContext.default.Provider, {
    value: auth
  }, /*#__PURE__*/_react.default.createElement(_FileManagerContext.default.Provider, {
    value: uploadState
  }, /*#__PURE__*/_react.default.createElement(_FileManagerCurrentContext.default.Provider, {
    value: currentState
  }, /*#__PURE__*/_react.default.createElement(_Directory.default, {
    initialView: initialView
  }))));
};

FileManager.defaultProps = {
  canCreate: true,
  canDelete: true,
  canEdit: true,
  canSee: true,
  initialView: 'list'
};
FileManager.propTypes = {
  collectionName: _propTypes.default.string.isRequired,
  id: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]).isRequired,
  canCreate: _propTypes.default.bool,
  canDelete: _propTypes.default.bool,
  canEdit: _propTypes.default.bool,
  canSee: _propTypes.default.bool,
  initialView: _propTypes.default.string
};
var _default = FileManager;
exports.default = _default;