"use strict";

var _react = _interopRequireDefault(require("react"));

var _CircularProgress = _interopRequireDefault(require("@material-ui/core/CircularProgress"));

var _enzymeUtils = require("q3-ui-test-utils/lib/enzymeUtils");

var _FileManager = _interopRequireDefault(require("./FileManager"));

var _AlertAuthError = _interopRequireDefault(require("../AlertAuthError"));

var _AlertFetchingError = _interopRequireDefault(require("../AlertFetchingError"));

var _useFileManagerInit = _interopRequireDefault(require("../useFileManagerInit"));

var _useUploads = _interopRequireDefault(require("../useUploads"));

var _useUploadsAuth = _interopRequireDefault(require("../useUploadsAuth"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.mock('../useUploadsAuth');
jest.mock('../useFileManagerInit');
jest.mock('../useUploads');

const checkExistenceOf = El => (0, _enzymeUtils.exists)(global.shallow( /*#__PURE__*/_react.default.createElement(_FileManager.default, {
  collectionName: "foo",
  id: "bar"
})).find(El));

describe('FileManager', () => {
  it('should show loading indicator when not initialized', () => {
    _useUploadsAuth.default.mockReturnValue({});

    _useFileManagerInit.default.mockReturnValue(false);

    _useUploads.default.mockReturnValue({});

    checkExistenceOf(_CircularProgress.default);
  });
  it('should show loading indicator when fetching', () => {
    _useUploadsAuth.default.mockReturnValue({});

    _useFileManagerInit.default.mockReturnValue(true);

    _useUploads.default.mockReturnValue({
      fetching: true
    });

    checkExistenceOf(_CircularProgress.default);
  });
  it('should show fetching error', () => {
    _useUploadsAuth.default.mockReturnValue({
      canSee: true
    });

    _useFileManagerInit.default.mockReturnValue(true);

    _useUploads.default.mockReturnValue({
      fetching: false,
      fetchingError: true
    });

    checkExistenceOf(_AlertFetchingError.default);
  });
  it('should show auth error', () => {
    _useUploadsAuth.default.mockReturnValue({
      canSee: false
    });

    _useFileManagerInit.default.mockReturnValue(true);

    _useUploads.default.mockReturnValue({});

    checkExistenceOf(_AlertAuthError.default);
  });
});