"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _q3UiHelpers = require("q3-ui-helpers");

var _FileManagerBatchContext = _interopRequireDefault(require("../FileManagerBatchContext"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useDialog = (dialogId, args = {}) => {
  const [data, setData] = _react.default.useState(null);

  const {
    enable,
    disable
  } = _react.default.useContext(_FileManagerBatchContext.default);

  const attr = 'data-props';

  const getElement = () => document.getElementById(dialogId);

  const setAttribute = value => {
    const el = getElement();
    el.setAttribute(attr, value);
    return el;
  };

  const open = (0, _utils.checkSsr)(() => {
    setAttribute(JSON.stringify(args)).click();
  });
  const close = (0, _utils.checkSsr)(() => {
    setAttribute('');
  });

  const handleAttribute = el => {
    try {
      setData(JSON.parse(el.getAttribute(attr)));
    } catch (e) {
      setData(null);
    }
  };

  const handleOpen = (ev, next) => {
    handleAttribute(getElement());
    next();
  };

  _react.default.useEffect(() => {
    if (!_q3UiHelpers.browser.isBrowserReady()) return undefined;
    const observer = new MutationObserver(([{
      target
    }]) => {
      handleAttribute(target);
    });
    const el = document.getElementById(dialogId);
    if (!el || !(el instanceof Node)) return undefined;
    observer.observe(el, {
      attributes: true
    });
    return () => {
      observer.disconnect();
    };
  }, []);

  return {
    close,
    data,
    handleOpen,
    open,
    isOpen: Boolean(data),
    TransitionProps: {
      onEnter() {
        disable();
      },

      onExit() {
        enable();
      }

    }
  };
};

var _default = useDialog;
exports.default = _default;