"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _lodash = require("lodash");

var _browserImageCompression = _interopRequireDefault(require("browser-image-compression"));

var _FileManagerContext = _interopRequireDefault(require("../FileManagerContext"));

var _FileManagerCurrentContext = _interopRequireDefault(require("../FileManagerCurrentContext"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useDropZoneAcceptedFiles = () => {
  const {
    post
  } = _react.default.useContext(_FileManagerContext.default);

  const {
    current
  } = _react.default.useContext(_FileManagerCurrentContext.default);

  const [pending, setPending] = _react.default.useState([]);

  const clearPending = () => setPending([]);

  const markPendingWithErrorProperty = () => setPending(prevState => (0, _lodash.map)(prevState, file => ({ ...file,
    error: true
  })));

  const onDrop = async acceptedFiles => {
    setPending(acceptedFiles);

    try {
      const f = new FormData();
      await Promise.all((0, _lodash.map)(acceptedFiles, async item => {
        let data = item;
        const originalName = item.name;

        try {
          data = await (0, _browserImageCompression.default)(data, {
            maxSizeMB: 4.5,
            useWebWorker: true,
            maxWidthOrHeight: 1920
          });
        } catch (e) {// noop
        }

        f.append(item.name, data, current ? `[${current}]${originalName}` : originalName);
      }));
      await post(f);
      clearPending();
    } catch (e) {
      markPendingWithErrorProperty();
    }
  };

  return {
    markPendingWithErrorProperty,
    onDrop,
    pending
  };
};

var _default = useDropZoneAcceptedFiles;
exports.default = _default;