"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _selecto = _interopRequireDefault(require("selecto"));

var _lodash = require("lodash");

var _q3UiHelpers = require("q3-ui-helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useMultiSelect = () => {
  const container = _react.default.useRef();

  const selectoInstance = _react.default.useRef();

  const [disabled, setDisabled] = _react.default.useState(false);

  const [selected, setSelected] = _react.default.useState([]);

  const formatId = fn => (id, ...rest) => fn((0, _lodash.split)(id, ','), ...rest);

  const isSelected = _react.default.useCallback(str => {
    const id = (0, _lodash.split)(str, ',');
    return Array.isArray(id) ? id.every(selected.includes.bind(selected)) : selected.includes(id);
  }, [selected]);

  const select = formatId((id, continueSelection = false) => setSelected(prevValue => continueSelection ? (0, _lodash.uniq)(prevValue.concat(id)) : _q3UiHelpers.array.is(id)));
  const deselect = formatId(id => setSelected(prevValue => (0, _lodash.filter)(prevValue, item => Array.isArray(id) ? !id.includes(item) : item !== id)));

  const clearSelected = () => {
    setSelected([]);
  };

  const preventWhenDisabled = fn => (...params) => disabled ? null : fn(...params);

  const enable = () => setDisabled(false);

  const disable = () => setDisabled(true);

  _react.default.useEffect(() => {
    selectoInstance.current = new _selecto.default({
      container: container.current,
      dragContainer: container.current,
      hitRate: 0.01,
      selectableTargets: ['.q3-file', '.q3-folder', '.q3-toolbar'],
      selectByClick: false,
      selectFromInside: false
    });
    selectoInstance.current.on('select', preventWhenDisabled(e => {
      if (!(0, _lodash.size)(e.selected)) return;

      const forEachNode = (key, action) => (0, _lodash.forEach)((0, _lodash.get)(e, key), node => {
        const id = node.getAttribute('data-id');
        if (id) action(id, true);
      });

      forEachNode('added', select);
      forEachNode('removed', deselect);
    }));
    selectoInstance.current.on('dragEnd', preventWhenDisabled(() => {
      disable(); // just enough time to not trigger other click actions

      const fn = (0, _lodash.debounce)(enable, 25);
      fn();
    }));
  }, []);

  return {
    clearSelected,
    container,
    deselect,
    disable,
    disabled,
    enable,
    isSelected,
    select,
    selected,
    sizeOfSelected: (0, _lodash.size)(selected)
  };
};

var _default = useMultiSelect;
exports.default = _default;