"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withQueryParamIds = exports.toPixels = exports.toMbs = exports.suppressEvent = exports.sanitize = exports.normalize = exports.makePrivateKey = exports.makeDirectoryId = exports.isTouchDevice = exports.getLastFolder = exports.getKey = exports.getFromLocalStorage = exports.getFileType = exports.convertSlashIntoDotNotation = exports.checkSsr = exports.checkContains = exports.castPropertyToLowerCase = void 0;

var _lodash = require("lodash");

var _q3UiHelpers = require("q3-ui-helpers");

const checkSsr = fn => (...params) => _q3UiHelpers.browser.isBrowserReady() ? fn(...params) : null;

exports.checkSsr = checkSsr;

const castPropertyToLowerCase = propertyName => item => String((0, _lodash.get)(item, propertyName)).toLowerCase();

exports.castPropertyToLowerCase = castPropertyToLowerCase;

const checkContains = (selector, target) => _q3UiHelpers.browser.isBrowserReady() ? (0, _lodash.some)(document.querySelectorAll(selector), node => node.contains(target)) : true;

exports.checkContains = checkContains;

const getFileType = url => {
  const defaultValue = null;

  try {
    return (0, _lodash.last)(new URL(url).pathname.split('.')) || defaultValue;
  } catch (e) {
    return defaultValue;
  }
};

exports.getFileType = getFileType;

const normalize = xs => ['', 'null', 'undefined'].includes(String(xs)) ? null : xs;

exports.normalize = normalize;

const getLastFolder = str => (0, _lodash.last)(String(str).split('/'));

exports.getLastFolder = getLastFolder;

const suppressEvent = (e, fn) => {
  if ((0, _lodash.isObject)(e)) {
    e.preventDefault();
    e.stopPropagation();
  }

  fn(e);
};

exports.suppressEvent = suppressEvent;

const convertSlashIntoDotNotation = str => (0, _lodash.replace)(str, /\//g, '.');

exports.convertSlashIntoDotNotation = convertSlashIntoDotNotation;

const makePrivateKey = (str = undefined) => (0, _lodash.isString)(str) ? `__${getLastFolder(str)}__` : '__null__';

exports.makePrivateKey = makePrivateKey;

const makeDirectoryId = (path = '', xs = {}) => {
  const recursivelyGetIds = ob => {
    if (Array.isArray(ob)) return ob.flatMap(v => (0, _lodash.get)(v, 'id'));
    return (0, _lodash.isObject)(ob) ? Object.values(ob).flatMap(recursivelyGetIds) : [];
  };

  return recursivelyGetIds((0, _lodash.get)(xs, convertSlashIntoDotNotation(path), {})).flat().sort().join(',');
};

exports.makeDirectoryId = makeDirectoryId;

const toMbs = (bytes = 0) => `${Number(bytes / 1024 ** 2).toFixed(2)}mbs`;

exports.toMbs = toMbs;

const toPixels = pixels => `${pixels}px`;

exports.toPixels = toPixels;

const sanitize = s => {
  if (!(0, _lodash.isString)(s)) return undefined;
  const punctuationless = s.replace(/[.,/#!$%^&*;:{}=\-_`~()]/g, '');
  return punctuationless.replace(/\s{2,}/g, ' ');
};

exports.sanitize = sanitize;

const withQueryParamIds = str => String(str).includes(',') ? `?ids=${str}` : str;

exports.withQueryParamIds = withQueryParamIds;

const getKey = k => `q3-filemanager-${k}`;

exports.getKey = getKey;

const getFromLocalStorage = (k, defaultValue) => {
  const prev = _q3UiHelpers.browser.proxyLocalStorageApi('getItem', getKey(k));

  return (0, _lodash.isNil)(normalize(prev)) ? defaultValue : prev;
};

exports.getFromLocalStorage = getFromLocalStorage;

const isTouchDevice = () => {
  var _window$matchMedia;

  return _q3UiHelpers.browser.isBrowserReady() && (0, _lodash.isFunction)(window.matchMedia) && ((_window$matchMedia = window.matchMedia('(pointer: coarse)')) === null || _window$matchMedia === void 0 ? void 0 : _window$matchMedia.matches);
};

exports.isTouchDevice = isTouchDevice;